%param
PDF_generation = 1;%O for EMF file, 1 for PDF file
linewidth_IPIN = 1;
MarkerSize_IPIN = 15;
team = 'estimations';

% load ground truth
GT = csvread('GT\GroundTruth_Track3.csv');
%load competitor log
filename='sample_output_01.csv';

%open current file
CL = csvread([team,'\',filename]);

%filter out index=0
I = find(CL(:,5) == 0);
CL(I,:)=[];

% output KML
% for GT
kmlwriteline([team,'\','trace_GT.kml'], GT(:,3), GT(:,2), 'Color','green', 'LineWidth', 3);
% for CL
kmlwriteline([team,'\','trace_Competitor.kml'], CL(:,3), CL(:,2), 'Color','blue', 'LineWidth', 3);

%% transform geo to ned
%tangence point : lower left point of Ground Truth
lat0  = min(GT(:,3));
lon0  = min(GT(:,2));
h0    = 79.765;%default
% altitude hyp : mme que base
h=ones(length(GT(:,1)),1)*h0;

% for GT
[xNorth_GT,yEast_GT,zDown_GT] = geodetic2ned(GT(:,3),GT(:,2),h,lat0,lon0,h0,wgs84Ellipsoid('meters'));
% for CL
[xNorth_CL,yEast_CL,zDown_CL] = geodetic2ned(CL(:,3),CL(:,2),h,lat0,lon0,h0,wgs84Ellipsoid('meters'));

%% comptutation of Distance(Ri,Ei) and SampleError
Distance_Ri_Ei = sqrt((xNorth_GT-xNorth_CL).^2 + (yEast_GT-yEast_CL).^2);
h4=figure;
if (PDF_generation == 1) subplot(3,2,1);end;
plot(Distance_Ri_Ei, '-o', 'linewidth', linewidth_IPIN);
mytitle = ['Distance(Ri,Ei)-',team];
title(mytitle)
if (PDF_generation == 0) print(gcf,[team,'\',mytitle],'-dmeta'); end;

SampleError=Distance_Ri_Ei + 15*abs(GT(:,4)-CL(:,4));
if (PDF_generation == 1) subplot(3,2,3);else figure; end;
plot(SampleError, '-o', 'linewidth', linewidth_IPIN);
mytitle = ['SampleError-',team];
title(mytitle)
if (PDF_generation == 0) print(gcf,[team,'\',mytitle],'-dmeta'); end;

%floor error
if (PDF_generation == 1) subplot(3,2,2);else figure; end;
plot(GT(:,4),'.g','MarkerSize',MarkerSize_IPIN)
hold on;
plot(CL(:,4),'-b','linewidth', linewidth_IPIN);
plot(abs(GT(:,4)-CL(:,4)),'.r','MarkerSize',MarkerSize_IPIN*0.5);
mytitle = ['Floor evaluation-',team];
legend('ground truth', 'competitor','floor error');title(mytitle)
if (PDF_generation == 0) print(gcf,[team,'\',mytitle],'-dmeta'); end;

%% plot graph2D Competitor vs GroundTruth (All floor)
if (PDF_generation == 1) subplot(3,2,5);else figure; end;
plot(yEast_GT,xNorth_GT,'.g','MarkerSize',MarkerSize_IPIN);
hold on
plot(yEast_CL,xNorth_CL,'-b','linewidth', linewidth_IPIN);
axis equal

%draw each local error
for nbpts = 1:length(yEast_GT)
    l = line([yEast_CL(nbpts), yEast_GT(nbpts)],[xNorth_CL(nbpts), xNorth_GT(nbpts)]);
    set(l, 'Color', 'm','linewidth', linewidth_IPIN);
end;
legend_text = {'ground truth', 'competitor', 'error'};
legend(legend_text);
xlabel('abscissa (m)');
ylabel('ordinates (m)');

mytitle = ['Distance(Ri,Ei) for All Floor','-',team];
title(mytitle);
if (PDF_generation == 0) print(gcf,[team,'\',mytitle],'-dmeta'); end;


%% CDF
if (PDF_generation == 1) subplot(3,2,4);else figure; end;
mytitle = ['SampleError distribution-',team];
title(mytitle);
SampleError_sort = sort(SampleError);
hold on%utile pourla trace de l'asymptote
plot(SampleError_sort,(1:size(SampleError_sort,1))/size(SampleError_sort,1),'linewidth',linewidth_IPIN)%plot ou  semilog
% ergonomie d'affichage
ylabel('CDF (%)');
%title(sprintf('receiver and antenna : %s',char(candidat_Type)));
xlabel('Horizontal Position Error (m)');
%axis([0 max_axe_metre 0 1.1]);
grid on;
set(gca,'YTick',[0.25 0.50 0.75 1.00])
set(gca,'YTickLabel',{'25';'50';'75';'100'})
% set(fig_CDF, 'Name', 'Errors distribution');
% set(fig_CDF, 'NumberTitle', 'off');
set(gcf, 'Name', 'Errors distribution');
set(gcf, 'NumberTitle', 'off');

%75 percentile
ThirdQuartil = quantile(SampleError,0.75);
%draw 75%
l = line([0, max(SampleError)], [0.75, 0.75]);
set(l, 'LineStyle', '--', 'Color', 'r', 'linewidth', linewidth_IPIN);
%draw Score
l = line([ThirdQuartil, ThirdQuartil], [0, 0.75]);
set(l, 'Color', 'r', 'linewidth', linewidth_IPIN);

%save
if (PDF_generation == 0) print(gcf,[team,'\',mytitle],'-dmeta'); end;

%% error stat
disp(['error stat (m)']);
disp(['median: ', num2str(median(SampleError),'%10.1f\n'), ' m']);
disp(['mean: ', num2str(mean(SampleError),'%10.1f\n'), ' m']);
disp(['rms: ', num2str(rms(SampleError),'%10.1f\n'), ' m']);
disp(['90th perc.: ', num2str(quantile(SampleError,0.90),'%10.1f\n'), ' m']);
disp(['75th perc.: ', num2str(ThirdQuartil,'%10.1f\n'), ' m']);

%result.txt
fid = fopen([team,'\','result_',team,'.txt'],'w');
fprintf(fid,'error stat (m)\n');
fprintf(fid,['median: ', num2str(median(SampleError),'%10.1f\n'), ' m\n']);
fprintf(fid,['mean: ', num2str(mean(SampleError),'%10.1f\n'), ' m\n']);
fprintf(fid,['rms: ', num2str(rms(SampleError),'%10.1f\n'), ' m\n']);
fprintf(fid,['90th perc.: ', num2str(quantile(SampleError,0.90),'%10.1f\n'), ' m\n']);
fprintf(fid,['75th perc.: ', num2str(ThirdQuartil,'%10.1f\n'), ' m']);
fclose(fid);

%% create PDF
if (PDF_generation == 1)
    %print result inside PDF as a legend
    subplot(3,2,6)
    plot(NaN)%
    axis off
    text(0,0.75,['error statistics'],'FontSize',20)
    text(0,0.60,['median: ', num2str(median(SampleError),'%10.1f\n'), ' m'],'FontSize',20)
    text(0,0.45,['mean: ', num2str(mean(SampleError),'%10.1f\n'), ' m'],'FontSize',20)
    text(0,0.30,['rms: ', num2str(rms(SampleError),'%10.1f\n'), ' m'],'FontSize',20)
    text(0,0.15,['90th perc.: ', num2str(quantile(SampleError,0.90),'%10.1f\n'), ' m'],'FontSize',20)
    text(0,0.0,['75th perc.: ', num2str(ThirdQuartil,'%10.1f\n'), ' m'],'FontSize',25)
    %print PDF
    set(h4,'PaperPositionMode','Auto')
    set(h4,'PaperSize',[29.7 42]); %set the paper size to A3
    print(h4,[team,'\','all-results'],'-fillpage','-dpdf') % then print it
    
    %draw All Floor in a separate PDF
    h5=figure;
    plot(yEast_GT,xNorth_GT,'.g','MarkerSize',MarkerSize_IPIN);
    hold on
    plot(yEast_CL,xNorth_CL,'-b','linewidth', linewidth_IPIN);
    axis equal
    
    %draw each local error
    for nbpts = 1:length(yEast_GT)
        l = line([yEast_CL(nbpts), yEast_GT(nbpts)],[xNorth_CL(nbpts), xNorth_GT(nbpts)]);
        set(l, 'Color', 'm','linewidth', linewidth_IPIN);
    end;
    legend_text = {'ground truth', 'competitor', 'error'};
    legend(legend_text);
    xlabel('abscissa (m)');
    ylabel('ordinates (m)');
    
    mytitle = ['Distance(Ri,Ei) for All Floor','-',team];
    title(mytitle);

    %print PDF
    set(h5,'PaperPositionMode','Auto')
    set(h5,'PaperSize',[29.7 42]); %set the paper size to A3
    print(h5,[team,'\','all-floors'],'-fillpage','-dpdf') % then print it
    
    
end;
